==> dojo_1.15.0+dfsg1.orig.tar.xz: dojo-release-1.15.0-src/dojo/cldr/nls/id/buddhist.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-second-relative+0": "sekarang",
	"field-weekday": "Hari dalam Seminggu",
	"field-wed-relative+0": "Rabu ini",
	"field-wed-relative+1": "Rabu berikutnya",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-MMMEd": "E, d MMM",
	"field-tue-relative+-1": "Selasa lalu",
	"days-format-short": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"dateFormat-long": "d MMMM y G",
	"field-fri-relative+-1": "Jumat lalu",
	"field-wed-relative+-1": "Rabu lalu",
	"months-format-wide": [
		"Januari",
		"Februari",
		"Maret",
		"April",
		"Mei",
		"Juni",
		"Juli",
		"Agustus",
		"September",
		"Oktober",
		"November",
		"Desember"
	],
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dateFormat-full": "EEEE, dd MMMM y G",
	"dateFormatItem-yyyyMEd": "E, d/M/y G",
	"field-thu-relative+-1": "Kamis lalu",
	"dateFormatItem-Md": "d/M",
	"field-era": "Era",
	"months-standAlone-wide": [
		"Januari",
		"Februari",
		"Maret",
		"April",
		"Mei",
		"Juni",
		"Juli",
		"Agustus",
		"September",
		"Oktober",
		"November",
		"Desember"
	],
	"timeFormat-short": "HH.mm",
	"quarters-format-wide": [
		"Kuartal ke-1",
		"Kuartal ke-2",
		"Kuartal ke-3",
		"Kuartal ke-4"
	],
	"timeFormat-long": "HH.mm.ss z",
	"field-year": "Tahun",
	"field-hour": "Jam",
	"months-format-abbr": [
		"Jan",
		"Feb",
		"Mar",
		"Apr",
		"Mei",
		"Jun",
		"Jul",
		"Agt",
		"Sep",
		"Okt",
		"Nov",
		"Des"
	],
	"field-sat-relative+0": "Sabtu ini",
	"field-sat-relative+1": "Sabtu berikutnya",
	"timeFormat-full": "HH.mm.ss zzzz",
	"field-day-relative+0": "hari ini",
	"field-thu-relative+0": "Kamis ini",
	"field-day-relative+1": "besok",
	"field-thu-relative+1": "Kamis berikutnya",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-day-relative+2": "lusa",
	"months-standAlone-abbr": [
		"Jan",
		"Feb",
		"Mar",
		"Apr",
		"Mei",
		"Jun",
		"Jul",
		"Agt",
		"Sep",
		"Okt",
		"Nov",
		"Des"
	],
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"quarters-standAlone-wide": [
		"Kuartal ke-1",
		"Kuartal ke-2",
		"Kuartal ke-3",
		"Kuartal ke-4"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E, d MMM y G",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"Minggu",
		"Senin",
		"Selasa",
		"Rabu",
		"Kamis",
		"Jumat",
		"Sabtu"
	],
	"dateFormatItem-yyyyMMM": "MMM y G",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"dateFormatItem-MMMMd": "d MMMM",
	"timeFormat-medium": "HH.mm.ss",
	"field-sun-relative+0": "hari Minggu ini",
	"dateFormatItem-Hm": "HH.mm",
	"field-sun-relative+1": "hari Minggu berikutnya",
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"eraAbbr": [
		"BE"
	],
	"field-minute": "Menit",
	"field-dayperiod": "AM/PM",
	"days-standAlone-abbr": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm.ss",
	"field-day-relative+-1": "kemarin",
	"dayPeriods-format-narrow-am": "AM",
	"field-day-relative+-2": "kemarin lusa",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E, d/M",
	"field-fri-relative+0": "Jumat ini",
	"field-fri-relative+1": "Jumat berikutnya",
	"field-day": "Hari",
	"days-format-wide": [
		"Minggu",
		"Senin",
		"Selasa",
		"Rabu",
		"Kamis",
		"Jumat",
		"Sabtu"
	],
	"field-zone": "Zona Waktu",
	"dateFormatItem-y": "G y",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-year-relative+-1": "tahun lalu",
	"field-month-relative+-1": "bulan lalu",
	"dateFormatItem-hm": "h.mm a",
	"days-format-abbr": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"days-format-narrow": [
		"M",
		"S",
		"S",
		"R",
		"K",
		"J",
		"S"
	],
	"dateFormatItem-yyyyMd": "d/M/y G",
	"field-month": "Bulan",
	"dateFormatItem-MMM": "LLL",
	"days-standAlone-narrow": [
		"M",
		"S",
		"S",
		"R",
		"K",
		"J",
		"S"
	],
	"field-tue-relative+0": "Selasa ini",
	"field-tue-relative+1": "Selasa berikutnya",
	"dateFormatItem-MMMMEd": "E, d MMMM",
	"field-mon-relative+0": "Senin ini",
	"field-mon-relative+1": "Senin berikutnya",
	"dateFormat-short": "d/M/y GGGGG",
	"field-second": "Detik",
	"field-sat-relative+-1": "Sabtu lalu",
	"field-sun-relative+-1": "hari Minggu lalu",
	"field-month-relative+0": "bulan ini",
	"field-month-relative+1": "Bulan berikutnya",
	"dateFormatItem-Ed": "E, d",
	"field-week": "Minggu",
	"dateFormat-medium": "d MMM y G",
	"field-year-relative+0": "tahun ini",
	"field-week-relative+-1": "minggu lalu",
	"dateFormatItem-yyyyM": "M/y G",
	"field-year-relative+1": "tahun depan",
	"dayPeriods-format-narrow-pm": "PM",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"dateFormatItem-Hms": "HH.mm.ss",
	"dateFormatItem-hms": "h.mm.ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "Senin lalu",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "minggu ini",
	"field-week-relative+1": "minggu berikutnya"
}
//end v1.x content
);

==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/id/buddhist.js <==
define(
//begin v1.x content
{
	"field-tue-relative+-1": "Selasa lalu",
	"field-year": "Tahun",
	"dateFormatItem-Hm": "HH.mm",
	"field-wed-relative+0": "Rabu ini",
	"field-wed-relative+1": "Rabu berikutnya",
	"dateFormatItem-ms": "mm.ss",
	"timeFormat-short": "HH.mm",
	"field-minute": "Menit",
	"field-tue-narrow-relative+0": "Sel. ini",
	"field-tue-narrow-relative+1": "Sel. berikutnya",
	"field-thu-short-relative+0": "Kam. ini",
	"field-thu-short-relative+1": "Kam. berikutnya",
	"field-day-relative+0": "hari ini",
	"field-day-relative+1": "besok",
	"field-day-relative+2": "lusa",
	"field-wed-narrow-relative+-1": "Rab. lalu",
	"field-year-narrow": "thn.",
	"field-tue-relative+0": "Selasa ini",
	"field-tue-relative+1": "Selasa berikutnya",
	"field-second-short": "dtk.",
	"dateFormatItem-MMMd": "d MMM",
	"field-week-relative+0": "minggu ini",
	"field-month-relative+0": "bulan ini",
	"field-week-relative+1": "minggu depan",
	"field-month-relative+1": "Bulan berikutnya",
	"field-sun-narrow-relative+0": "Min. ini",
	"timeFormat-medium": "HH.mm.ss",
	"field-mon-short-relative+0": "Sen. ini",
	"field-sun-narrow-relative+1": "Min. berikutnya",
	"field-mon-short-relative+1": "Sen. berikutnya",
	"field-second-relative+0": "sekarang",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-month-short": "bln.",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-yyyyMd": "d/M/y G",
	"field-day": "Hari",
	"field-year-relative+-1": "tahun lalu",
	"field-sat-short-relative+-1": "Sab. lalu",
	"field-hour-relative+0": "jam ini",
	"dateFormatItem-yyyyMEd": "E, d/M/y G",
	"field-wed-relative+-1": "Rabu lalu",
	"field-sat-narrow-relative+-1": "Sab. lalu",
	"field-second": "Detik",
	"days-standAlone-narrow": [
		"M",
		"S",
		"S",
		"R",
		"K",
		"J",
		"S"
	],
	"dateFormat-long": "d MMMM y G",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-quarter": "Kuartal",
	"field-week-short": "mgg.",
	"quarters-standAlone-wide": [
		"Kuartal ke-1",
		"Kuartal ke-2",
		"Kuartal ke-3",
		"Kuartal ke-4"
	],
	"days-format-narrow": [
		"M",
		"S",
		"S",
		"R",
		"K",
		"J",
		"S"
	],
	"field-tue-short-relative+0": "Sel. ini",
	"field-tue-short-relative+1": "Sel. berikutnya",
	"field-mon-relative+-1": "Senin lalu",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "Bulan",
	"field-day-narrow": "h",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "mnt.",
	"field-dayperiod": "AM/PM",
	"field-sat-short-relative+0": "Sab. ini",
	"field-sat-short-relative+1": "Sab. berikutnya",
	"dateFormat-medium": "d MMM y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"eraAbbr": [
		"BE"
	],
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"dateFormatItem-yyyyM": "M/y G",
	"field-second-narrow": "d",
	"field-mon-relative+0": "Senin ini",
	"field-mon-relative+1": "Senin berikutnya",
	"field-year-short": "thn.",
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-quarter-relative+-1": "Kuartal lalu",
	"dateFormatItem-yyyyMMMd": "d MMM y G",
	"days-format-short": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"field-sat-relative+-1": "Sabtu lalu",
	"dateFormatItem-Md": "d/M",
	"field-hour": "Jam",
	"months-format-wide": [
		"Januari",
		"Februari",
		"Maret",
		"April",
		"Mei",
		"Juni",
		"Juli",
		"Agustus",
		"September",
		"Oktober",
		"November",
		"Desember"
	],
	"dateFormat-full": "EEEE, dd MMMM y G",
	"field-month-relative+-1": "bulan lalu",
	"dateFormatItem-Hms": "HH.mm.ss",
	"field-quarter-short": "krtl.",
	"field-sat-narrow-relative+0": "Sab. ini",
	"field-fri-relative+0": "Jumat ini",
	"field-sat-narrow-relative+1": "Sab. berikutnya",
	"field-fri-relative+1": "Jumat berikutnya",
	"field-sun-short-relative+0": "Min. ini",
	"field-sun-short-relative+1": "Min. berikutnya",
	"field-week-relative+-1": "minggu lalu",
	"months-format-abbr": [
		"Jan",
		"Feb",
		"Mar",
		"Apr",
		"Mei",
		"Jun",
		"Jul",
		"Agt",
		"Sep",
		"Okt",
		"Nov",
		"Des"
	],
	"field-quarter-relative+0": "Kuartal ini",
	"field-minute-relative+0": "menit ini",
	"timeFormat-long": "HH.mm.ss z",
	"field-quarter-relative+1": "Kuartal berikutnya",
	"field-wed-short-relative+-1": "Rab. lalu",
	"dateFormat-short": "d/M/y GGGGG",
	"field-thu-short-relative+-1": "Kam. lalu",
	"days-standAlone-wide": [
		"Minggu",
		"Senin",
		"Selasa",
		"Rabu",
		"Kamis",
		"Jumat",
		"Sabtu"
	],
	"dateFormatItem-yyyyMMMEd": "E, d MMM y G",
	"field-mon-narrow-relative+-1": "Sen. lalu",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "Kam. lalu",
	"field-tue-narrow-relative+-1": "Sel. lalu",
	"dateFormatItem-yyyy": "y G",
	"field-wed-short-relative+0": "Rab. ini",
	"dateFormatItem-M": "L",
	"months-standAlone-wide": [
		"Januari",
		"Februari",
		"Maret",
		"April",
		"Mei",
		"Juni",
		"Juli",
		"Agustus",
		"September",
		"Oktober",
		"November",
		"Desember"
	],
	"field-wed-short-relative+1": "Rab. berikutnya",
	"field-sun-relative+-1": "hari Minggu lalu",
	"dateFormatItem-MMMMEd": "E, d MMMM",
	"days-standAlone-abbr": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"dateFormatItem-hm": "h.mm a",
	"dateFormatItem-d": "d",
	"field-weekday": "Hari dalam Seminggu",
	"field-sat-relative+0": "Sabtu ini",
	"field-sat-relative+1": "Sabtu berikutnya",
	"months-standAlone-abbr": [
		"Jan",
		"Feb",
		"Mar",
		"Apr",
		"Mei",
		"Jun",
		"Jul",
		"Agt",
		"Sep",
		"Okt",
		"Nov",
		"Des"
	],
	"timeFormat-full": "HH.mm.ss zzzz",
	"dateFormatItem-MEd": "E, d/M",
	"dateFormatItem-y": "G y",
	"field-thu-narrow-relative+0": "Kam. ini",
	"field-thu-narrow-relative+1": "Kam. berikutnya",
	"field-sun-narrow-relative+-1": "Min. lalu",
	"field-mon-short-relative+-1": "Sen. lalu",
	"field-thu-relative+0": "Kamis ini",
	"field-thu-relative+1": "Kamis berikutnya",
	"dateFormatItem-hms": "h.mm.ss a",
	"field-fri-short-relative+-1": "Jum. lalu",
	"field-thu-relative+-1": "Kamis lalu",
	"field-week": "Minggu",
	"quarters-format-wide": [
		"Kuartal ke-1",
		"Kuartal ke-2",
		"Kuartal ke-3",
		"Kuartal ke-4"
	],
	"dateFormatItem-Ed": "E, d",
	"field-wed-narrow-relative+0": "Rab. ini",
	"field-wed-narrow-relative+1": "Rab. berikutnya",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-fri-short-relative+0": "Jum. ini",
	"field-fri-short-relative+1": "Jum. berikutnya",
	"days-standAlone-short": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "jam",
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"field-month-narrow": "bln.",
	"field-hour-narrow": "j",
	"field-fri-narrow-relative+-1": "Jum. lalu",
	"field-year-relative+0": "tahun ini",
	"field-year-relative+1": "tahun depan",
	"field-fri-relative+-1": "Jumat lalu",
	"field-tue-short-relative+-1": "Sel. lalu",
	"field-minute-narrow": "m",
	"days-format-wide": [
		"Minggu",
		"Senin",
		"Selasa",
		"Rabu",
		"Kamis",
		"Jumat",
		"Sabtu"
	],
	"field-mon-narrow-relative+0": "Sen. ini",
	"field-mon-narrow-relative+1": "Sen. berikutnya",
	"field-zone": "Zona Waktu",
	"dateFormatItem-MMMEd": "E, d MMM",
	"field-quarter-narrow": "krtl.",
	"field-sun-short-relative+-1": "Min. lalu",
	"field-day-relative+-1": "kemarin",
	"field-day-relative+-2": "kemarin dulu",
	"days-format-abbr": [
		"Min",
		"Sen",
		"Sel",
		"Rab",
		"Kam",
		"Jum",
		"Sab"
	],
	"field-sun-relative+0": "hari Minggu ini",
	"field-sun-relative+1": "hari Minggu berikutnya",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "h",
	"field-week-narrow": "mgg.",
	"field-era": "Era",
	"field-fri-narrow-relative+0": "Jum. ini",
	"field-fri-narrow-relative+1": "Jum. berikutnya"
}
//end v1.x content
);
